==> lowcode-editor-skeleton-2.0.5.tgz: package/es/plugins/plugin-variable-bind/index.js <==
import _Space from "antd/es/space";
import _Button from "antd/es/button";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _message from "antd/es/message";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React, { useEffect, useState } from 'react';
import cls from 'classnames';
import { isJSExpression } from '@gant-lowcode/lowcode-utils';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
import { useStyle } from './style';
import { createForm } from '@formily/core';
import { ExpressionSetter } from './expression-setter';
import { extractReferencedIdentifiers, getAssignmentCode, hasInVariables } from './utils';
export var VariableBind = function VariableBind(_props) {
  var commonUI = _props.commonUI,
    className = _props.className,
    engineConfig = _props.engineConfig,
    event = _props.event;
  var Modal = commonUI.Modal;
  var _message$useMessage = _message.useMessage(),
    messageApi = _message$useMessage[0],
    contextHolder = _message$useMessage[1];
  var _useState = useState(),
    selected = _useState[0],
    setSelected = _useState[1];
  var _useState2 = useState(),
    field = _useState2[0],
    setField = _useState2[1];
  var prefixCls = usePrefixCls('variable-bind');
  var _useStyle = useStyle(prefixCls),
    wrapSSR = _useStyle[0],
    hashId = _useStyle[1];
  var _useState3 = useState({}),
    props = _useState3[0],
    setProps = _useState3[1];
  var _useState4 = useState({}),
    values = _useState4[0],
    onChange = _useState4[1];
  var _useState5 = useState(false),
    isModalOpen = _useState5[0],
    setIsModalOpen = _useState5[1];
  var _useState6 = useState(null),
    form = _useState6[0],
    setForm = _useState6[1];
  var showModal = function showModal() {
    setIsModalOpen(true);
  };
  useEffect(function () {
    return event.on('common:variableBind.open', function (props, field, selected) {
      setProps(props);
      setField(field);
      setSelected(selected);
      var values = {
        type: 'JSExpression',
        isFixed: false,
        variableName: '',
        mock: props.value,
        statementId: ''
      };
      console.log('-VariableBind----props', props);
      if (isJSExpression(props.value)) {
        if (props.value.isFixed) {
          var statement = selected.getStatementById(props.value.statementId);
          console.log('-VariableBind----props.statementId', props.value.statementId);
          values = _extends({}, props.value, {
            value: getAssignmentCode(statement.value)
          });
        } else {
          values = props.value;
        }
        onChange(values);
      } else {
        onChange(values);
      }
      setForm(createForm({
        initialValues: values
      }));
      showModal();
    });
  }, [event]);
  var getMockOrValue = function getMockOrValue() {
    var v = props.value;
    if (isJSExpression(v)) {
      return v.mock;
    }
    return v;
  };
  var disabled = !isJSExpression(props.value);
  var handleCancel = function handleCancel() {
    setIsModalOpen(false);
  };
  var systemVariableOptionsTree = engineConfig.get('systemVariableOptionsTree', []);
  var handleOk = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var values, finalValue, statementId, statement, isCircular, isDefined, identifiers, prop;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return form.validate();
          case 2:
            values = form.values;
            console.log('----values', values);
            statementId = selected.id + "_" + field.path.toString();
            statement = {
              type: 'JsVarDeclaration',
              id: statementId,
              name: values.variableName,
              value: "const " + values.variableName + " = " + values.value + ";",
              source: "const " + values.variableName + " = " + values.value + ";",
              references: [statementId]
            }; // 定义变量 是否循环引用
            isCircular = false;
            isDefined = false;
            identifiers = extractReferencedIdentifiers(values.value);
            identifiers.forEach(function (identifier) {
              if (identifier === values.variableName) {
                messageApi.warning("\u53D8\u91CF" + identifier + "\u4E0D\u80FD\u5F15\u7528\u81EA\u8EAB");
                isCircular = true;
                return;
              }
              var isSystemVariable = hasInVariables(systemVariableOptionsTree, identifier);
              if (!selected.hasStatement({
                name: identifier
              }) && !isSystemVariable) {
                messageApi.warning("\u53D8\u91CF" + identifier + "\u4E0D\u5B58\u5728");
                isDefined = true;
                return;
              }
              // 如果使用的是系统变量，不添加引用
              if (!isSystemVariable) {
                selected.addStatementReference(identifier, statementId);
              }
            });
            if (!(isCircular || isDefined)) {
              _context.next = 12;
              break;
            }
            return _context.abrupt("return");
          case 12:
            if (!values.isFixed) {
              _context.next = 21;
              break;
            }
            if (!selected.hasStatement(statement)) {
              _context.next = 16;
              break;
            }
            messageApi.warning("\u5DF2\u5B58\u5728\u540D\u5B57\u4E3A" + values.variableName + "\u7684\u53D8\u91CF");
            return _context.abrupt("return");
          case 16:
            prop = selected.addStatements(statement);
            console.log('作为页面变量', statement, selected, prop);
            finalValue = _extends({}, values, {
              type: 'JSExpression',
              value: values.variableName,
              mock: getMockOrValue(),
              statementId: statementId
            });
            _context.next = 23;
            break;
          case 21:
            selected.removeStatements(statement);
            finalValue = _extends({}, values, {
              type: 'JSExpression',
              mock: getMockOrValue()
            });
          case 23:
            Promise.resolve().then(function () {
              var _props$onChange;
              (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, finalValue);
            });
            handleCancel();
          case 25:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function handleOk() {
      return _ref.apply(this, arguments);
    };
  }();
  var removeBind = function removeBind() {
    if (!disabled) {
      var statementId = selected.id + "_" + field.path.toString();
      var statement = {
        type: 'JsVarDeclaration',
        name: values.variableName,
        value: "const " + values.variableName + " = " + values.value + ";",
        source: "const " + values.variableName + " = " + values.value + ";",
        id: statementId,
        references: [statementId]
      };
      selected.removeStatements(statement);
      props.onChange(getMockOrValue());
      handleCancel();
    }
  };
  var footer = /*#__PURE__*/React.createElement("div", {
    className: prefixCls + "-footer"
  }, /*#__PURE__*/React.createElement(_Button, {
    color: "danger",
    variant: "outlined",
    onClick: removeBind,
    disabled: disabled
  }, "\u5220\u9664\u903B\u8F91"), /*#__PURE__*/React.createElement(_Space, null, /*#__PURE__*/React.createElement(_Button, {
    onClick: handleCancel
  }, "\u53D6\u6D88"), /*#__PURE__*/React.createElement(_Button, {
    type: "primary",
    onClick: handleOk
  }, "\u786E\u5B9A")));
  return wrapSSR(/*#__PURE__*/React.createElement(React.Fragment, null, contextHolder, /*#__PURE__*/React.createElement(Modal, {
    className: cls(prefixCls, hashId, className),
    title: "\u903B\u8F91\u7F16\u8F91\u5668",
    open: isModalOpen,
    onCancel: handleCancel,
    destroyOnClose: true,
    onOk: handleOk,
    width: 900,
    footer: footer
  }, /*#__PURE__*/React.createElement(ExpressionSetter, {
    selected: selected,
    config: engineConfig,
    form: form
  }))));
};

==> lowcode-editor-skeleton-2.0.7.tgz: package/es/plugins/plugin-variable-bind/index.js <==
import _Space from "antd/es/space";
import _Button from "antd/es/button";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _message from "antd/es/message";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React, { useEffect, useState } from 'react';
import cls from 'classnames';
import { isJSExpression } from '@gant-lowcode/lowcode-utils';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
import { useStyle } from './style';
import { createForm } from '@formily/core';
import { ExpressionSetter } from './expression-setter';
import { extractReferencedIdentifiers, getAssignmentCode, hasInVariables } from './utils';
export var VariableBind = function VariableBind(_props) {
  var commonUI = _props.commonUI,
    className = _props.className,
    engineConfig = _props.engineConfig,
    event = _props.event;
  var Modal = commonUI.Modal;
  var _message$useMessage = _message.useMessage(),
    messageApi = _message$useMessage[0],
    contextHolder = _message$useMessage[1];
  var _useState = useState(),
    selected = _useState[0],
    setSelected = _useState[1];
  var _useState2 = useState(),
    field = _useState2[0],
    setField = _useState2[1];
  var prefixCls = usePrefixCls('variable-bind');
  var _useStyle = useStyle(prefixCls),
    wrapSSR = _useStyle[0],
    hashId = _useStyle[1];
  var _useState3 = useState({}),
    props = _useState3[0],
    setProps = _useState3[1];
  var _useState4 = useState({}),
    values = _useState4[0],
    onChange = _useState4[1];
  var _useState5 = useState(false),
    isModalOpen = _useState5[0],
    setIsModalOpen = _useState5[1];
  var _useState6 = useState(null),
    form = _useState6[0],
    setForm = _useState6[1];
  var showModal = function showModal() {
    setIsModalOpen(true);
  };
  useEffect(function () {
    return event.on('common:variableBind.open', function (props, field, selected) {
      setProps(props);
      setField(field);
      setSelected(selected);
      var values = {
        type: 'JSExpression',
        isFixed: false,
        variableName: '',
        mock: props.value,
        statementId: ''
      };
      console.log('-VariableBind----props', props);
      if (isJSExpression(props.value)) {
        if (props.value.isFixed) {
          var statement = selected.getStatementById(props.value.statementId);
          console.log('-VariableBind----props.statementId', props.value.statementId);
          values = _extends({}, props.value, {
            value: getAssignmentCode(statement.value)
          });
        } else {
          values = props.value;
        }
        onChange(values);
      } else {
        onChange(values);
      }
      setForm(createForm({
        initialValues: values
      }));
      showModal();
    });
  }, [event]);
  var getMockOrValue = function getMockOrValue() {
    var v = props.value;
    if (isJSExpression(v)) {
      return v.mock;
    }
    return v;
  };
  var disabled = !isJSExpression(props.value);
  var handleCancel = function handleCancel() {
    setIsModalOpen(false);
  };
  var systemVariableOptionsTree = engineConfig.get('systemVariableOptionsTree', []);
  var handleOk = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var values, finalValue, statementId, statement, isCircular, isDefined, identifiers;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return form.validate();
          case 2:
            values = form.values;
            console.log('----values', values);
            statementId = selected.id + "_" + field.path.toString();
            statement = {
              type: 'JsVarDeclaration',
              id: statementId,
              name: values.variableName,
              value: "const " + values.variableName + " = " + values.value + ";",
              source: "const " + values.variableName + " = " + values.value + ";",
              references: [statementId]
            }; // 定义变量 是否循环引用
            isCircular = false;
            isDefined = false;
            identifiers = extractReferencedIdentifiers(values.value);
            identifiers.forEach(function (identifier) {
              if (identifier === values.variableName) {
                messageApi.warning("\u53D8\u91CF" + identifier + "\u4E0D\u80FD\u5F15\u7528\u81EA\u8EAB");
                isCircular = true;
                return;
              }
              var isSystemVariable = hasInVariables(systemVariableOptionsTree, identifier);
              if (!selected.hasStatement({
                name: identifier
              }) && !isSystemVariable) {
                messageApi.warning("\u53D8\u91CF" + identifier + "\u4E0D\u5B58\u5728");
                isDefined = true;
                return;
              }
              // 如果使用的是系统变量，不添加引用
              if (!isSystemVariable) {
                selected.addStatementReference(identifier, statementId);
              }
            });
            if (!(isCircular || isDefined)) {
              _context.next = 12;
              break;
            }
            return _context.abrupt("return");
          case 12:
            if (!values.isFixed) {
              _context.next = 20;
              break;
            }
            if (!selected.hasStatement(statement)) {
              _context.next = 16;
              break;
            }
            messageApi.warning("\u5DF2\u5B58\u5728\u540D\u5B57\u4E3A" + values.variableName + "\u7684\u53D8\u91CF");
            return _context.abrupt("return");
          case 16:
            selected.addStatements(statement);
            finalValue = _extends({}, values, {
              type: 'JSExpression',
              value: values.variableName,
              mock: getMockOrValue(),
              statementId: statementId
            });
            _context.next = 22;
            break;
          case 20:
            selected.removeStatements(statement);
            finalValue = _extends({}, values, {
              type: 'JSExpression',
              mock: getMockOrValue()
            });
          case 22:
            Promise.resolve().then(function () {
              var _props$onChange;
              (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, finalValue);
            });
            handleCancel();
          case 24:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function handleOk() {
      return _ref.apply(this, arguments);
    };
  }();
  var removeBind = function removeBind() {
    if (!disabled) {
      var statementId = selected.id + "_" + field.path.toString();
      var statement = {
        type: 'JsVarDeclaration',
        name: values.variableName,
        value: "const " + values.variableName + " = " + values.value + ";",
        source: "const " + values.variableName + " = " + values.value + ";",
        id: statementId,
        references: [statementId]
      };
      selected.removeStatements(statement);
      props.onChange(getMockOrValue());
      handleCancel();
    }
  };
  var footer = /*#__PURE__*/React.createElement("div", {
    className: prefixCls + "-footer"
  }, /*#__PURE__*/React.createElement(_Button, {
    color: "danger",
    variant: "outlined",
    onClick: removeBind,
    disabled: disabled
  }, "\u5220\u9664\u903B\u8F91"), /*#__PURE__*/React.createElement(_Space, null, /*#__PURE__*/React.createElement(_Button, {
    onClick: handleCancel
  }, "\u53D6\u6D88"), /*#__PURE__*/React.createElement(_Button, {
    type: "primary",
    onClick: handleOk
  }, "\u786E\u5B9A")));
  return wrapSSR(/*#__PURE__*/React.createElement(React.Fragment, null, contextHolder, /*#__PURE__*/React.createElement(Modal, {
    className: cls(prefixCls, hashId, className),
    title: "\u903B\u8F91\u7F16\u8F91\u5668",
    open: isModalOpen,
    onCancel: handleCancel,
    destroyOnClose: true,
    onOk: handleOk,
    width: 900,
    footer: footer
  }, /*#__PURE__*/React.createElement(ExpressionSetter, {
    selected: selected,
    config: engineConfig,
    form: form
  }))));
};
